@@ -27,16 +27,20 @@ cleanuponerror() {
    exit 129 
 }
 
+if [ -n "$SKIP_REMOTE" ]; then
+   test_scripts_file="TEST_SCRIPTS_NOREMOTE"
+else
+   test_scripts_file="TEST_SCRIPTS"
+fi
+
 # allow tests to be commented out by beginning with the line with a '!'
 # remove bn_all_ef.jnl from the list if $efdir is "."
 if [ "$efdir" = "." ]; then
-   jnl_scripts=`grep -v '^!' TEST_SCRIPTS | grep '\.jnl$' | grep -v "bn_all_ef\.jnl"`
+   jnl_scripts=`grep -v '^!' $test_scripts_file | grep '\.jnl$' | grep -v "bn_all_ef\.jnl"`
 else
-   jnl_scripts=`grep -v '^!' TEST_SCRIPTS | grep '\.jnl$'`
+   jnl_scripts=`grep -v '^!' $test_scripts_file | grep '\.jnl$'`
 fi
-py_scripts=`grep -v '^!' TEST_SCRIPTS | grep '\.py$'`
-
-umask 002
+py_scripts=`grep -v '^!' $test_scripts_file | grep '\.py$'`
 
 # Get the machine type for the stream file testing
 if [ `uname -s` = "Linux" -a `uname -m` = "x86_64" ]; then
@@ -221,76 +225,88 @@ exeferdir=`dirname $exebindir | sed -e 's/\\//\\\\\\//g'`
 echo "s/$exeferdir/....../g" >> $cleanups
 
 timeregex=`date +%0d.%h.%Y`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/${timeregex}/DD-MON-YYYY/g" >> $cleanups
 timeregex=`date +%0d.%h.%Y | tr [a-z] [A-Z]`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/${timeregex}/DD-MON-YYYY/g" >> $cleanups
 timeregex=`date +%_d.%h.%Y`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/${timeregex}/DD-MON-YYYY/g" >> $cleanups
 timeregex=`date +%_d.%h.%Y | tr [a-z] [A-Z]`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/${timeregex}/DD-MON-YYYY/g" >> $cleanups
 # If date assigned to symbol and then symbol used elsewhere, any beginning space is dropped
 timeregex=`date +%-d.%h.%Y`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/\<${timeregex}/DD-MON-YYYY/g" >> $cleanups
 timeregex=`date +%-d.%h.%Y | tr [a-z] [A-Z]`
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
-echo "s/$timeregex.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YYYY/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM:SS/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YYYY HH:MM/g" >> $cleanups
+echo "s/\<${timeregex}/DD-MON-YYYY/g" >> $cleanups
 
 timeregex=`date +%0d.%h.%y`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\>/DD-MON-YY/g" >> $cleanups
 timeregex=`date +%0d.%h.%y | tr [a-z] [A-Z]`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\>/DD-MON-YY/g" >> $cleanups
 timeregex=`date +%_d.%h.%y`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\>/DD-MON-YY/g" >> $cleanups
 timeregex=`date +%_d.%h.%y | tr [a-z] [A-Z]`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/${timeregex}\>/DD-MON-YY/g" >> $cleanups
 # If date assigned to symbol and then symbol used elsewhere, any beginning space is dropped
 timeregex=`date +%-d.%h.%y`
-echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
-echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
+echo "s/\<${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/\<${timeregex}\>/DD-MON-YY/g" >> $cleanups
 timeregex=`date +%-d.%h.%y | tr [a-z] [A-Z]`
-echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
-echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/DD-MON-YY/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM:SS/g" >> $cleanups
+echo "s/\<${timeregex}.[0-9][0-9]:[0-9][0-9]/DD-MON-YY HH:MM/g" >> $cleanups
+echo "s/\<${timeregex}\$/DD-MON-YY/g" >> $cleanups
+echo "s/\<${timeregex}\>/DD-MON-YY/g" >> $cleanups
 
 timeregex=`date +%m.%d.%Y`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/MM-DD-YYYY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/MM-DD-YYYY HH:MM/g" >> $cleanups
-echo "s/$timeregex/MM-DD-YYYY/g" >> $cleanups
+echo "s/${timeregex}/MM-DD-YYYY/g" >> $cleanups
 
 timeregex=`date +%m.%d.%y`
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/MM-DD-YY HH:MM:SS/g" >> $cleanups
 echo "s/${timeregex}.[0-9][0-9]:[0-9][0-9]/MM-DD-YY HH:MM/g" >> $cleanups
-echo "s/$timeregex/MM-DD-YY/g" >> $cleanups
+echo "s/${timeregex}\$/MM-DD-YY/g" >> $cleanups
+echo "s/${timeregex}\>/MM-DD-YY/g" >> $cleanups
 
 timeregex=`date | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
-echo "s/$timeregex/WKD MON DD HH:MM:SS ZZZ YYYY/g" >> $cleanups
+echo "s/${timeregex}/WKD MON DD HH:MM:SS ZZZ YYYY/g" >> $cleanups
 timeregex=`date | tr [a-z] [A-Z] | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
-echo "s/$timeregex/WKD MON DD HH:MM:SS ZZZ YYYY/g" >> $cleanups
+echo "s/${timeregex}/WKD MON DD HH:MM:SS ZZZ YYYY/g" >> $cleanups
 
 timeregex=`date +%a.%h.%_d.%T.%Y | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
-echo "s/$timeregex/WKD MON DD HH:MM:SS YYYY/g" >> $cleanups
+echo "s/${timeregex}/WKD MON DD HH:MM:SS YYYY/g" >> $cleanups
 timeregex=`date +%a.%h.%_d.%T.%Y | tr [a-z] [A-Z] | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
-echo "s/$timeregex/WKD MON DD HH:MM:SS YYYY/g" >> $cleanups
+echo "s/${timeregex}/WKD MON DD HH:MM:SS YYYY/g" >> $cleanups
+
+timeregex=`date +%h.%_d.%T.%Y | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
+echo "s/${timeregex}/MON DD HH:MM:SS YYYY/g" >> $cleanups
+timeregex=`date +%h.%_d.%T.%Y | tr [a-z] [A-Z] | sed -e 's/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/'`
+echo "s/${timeregex}/MON DD HH:MM:SS YYYY/g" >> $cleanups
 
 echo 's/^randu2_randn2 [0-9 .-]+$/randu2_randn2      ....../' >> $cleanups
 echo 's/the_time = [0-9][0-9]:[0-9][0-9]/the_time = HH:MM/g' >> $cleanups
@@ -310,6 +326,10 @@ echo 's/DEFINE VARIABLE dt = 0\.[0-9]+/DEFINE VARIABLE dt = 0.######/' >> $clean
 echo 's/DEFINE VARIABLE sumcpu =[ ]?0\.[0-9]+/DEFINE VARIABLE sumcpu = 0.######/' >> $cleanups
 echo '/say `sumcpu`/,/sh sym CLOCK_SECS/ s/0\.[0-9]+/0.######/' >> $cleanups
 
+username=`id -un`
+groupname=`id -gn`
+echo "s/^[0-9]+ [0-9]+ [rw-]+ [0-9]+ ${username} ${groupname} /######## ######## ---------- # user group /" >> $cleanups
+
 sed $SED_EXTREGEX_FLAG -i_orig -f $cleanups $log_file
 sed $SED_EXTREGEX_FLAG -i_orig -f $cleanups $err_file
 sed $SED_EXTREGEX_FLAG -i_orig -f $cleanups $ncdump_file
