@@ -42,10 +42,9 @@
  */
 
 #include <string.h>
+#include "ferret.h"
 
-void c_strlen_(in_ptr, out_ptr)
-     char** in_ptr;
-     int* out_ptr;
+void FORTRAN(c_strlen)(char **in_ptr, int *out_ptr)
 {
    /* this treats an undefined string the same as an empty string */
    if ( *in_ptr == NULL )
