@@ -43,24 +43,14 @@
 #include <X11/Xutil.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include "ferret.h"
 #include "gks_implem.h"
-#include "wslist.h"
-
-#ifdef NO_ENTRY_NAME_UNDERSCORES
-void copy_buffered_window(ws_id, anim_id)
-#else
-void copy_buffered_window_(ws_id, anim_id)
-#endif
-     int *ws_id, *anim_id;
 
+void FORTRAN(copy_buffered_window)(int *ws_id, int *anim_id)
 {
-  WS_STATE_ENTRY *ws, *anim, *temp_win;
+  WS_STATE_ENTRY *ws, *anim;
   unsigned width, height;
-  XWindowAttributes win_info, anim_win_info;
-  int src_absx, src_absy, dest_absx, dest_absy;
-  int screen, tmp_id;
-  Window dummywin;
-  Pixmap pixmap;
+  XWindowAttributes win_info;
 
 /* determine the XGKS ws state entry structure from ws_id */
   ws  = OPEN_WSID (*ws_id);
@@ -75,8 +65,6 @@ void copy_buffered_window_(ws_id, anim_id)
       exit(1);
     }
   
-  screen = DefaultScreen(ws->dpy);
-  
   width = win_info.width;
   height = win_info.height;
 
