@@ -62,29 +62,15 @@
 #include <stdio.h>
 #include <string.h>
 #include "gks_implem.h"
-#include "wslist.h"
-#include "cgm/cgm.h"
-#include "cgm/cgm_implem.h"
 #include "ferret.h"
 
-FORTRAN(put_frame)( ws_id, filename, errstr, format, status )
-
-   char *filename, *errstr, *format;
-   int *ws_id, *status;
-
+void FORTRAN(put_frame)(int *ws_id, char *filename, char *errstr, char *format, int *status)
 {
   WS_STATE_ENTRY *ws;
-  Display *mydisplay;
-  Window   mywindow;
 
 /* determine the XGKS ws state entry structure from ws_id */
   ws  = OPEN_WSID (*ws_id);	
 
-/* the next 2 lines are diagnostic
-     mydisplay = ws->dpy;
-     mywindow  = ws->win;
-*/
-
 /* call up the capture routine */
 /* Errors internal to Window_Dump com out in errstr */
    Window_Dump(ws->win,ws->dpy,filename,format);
@@ -96,10 +82,9 @@ FORTRAN(put_frame)( ws_id, filename, errstr, format, status )
 /*  acm create separate GIFFlush routines for transparency. Passing the argumetns transp, red, green, blue
     in direcly into GIFFlush as arguments did not work on porter.
 */
-void FORTRAN(put_frame_batch)(int *ws_id, char *filename, char *format, int *transp, DFTYPE *red, DFTYPE *green,
-                              DFTYPE *blue, char *errmsg, int *status)
+void FORTRAN(put_frame_batch)(int *ws_id, char *filename, char *format, int *transp, 
+                              DFTYPE *red, DFTYPE *green, DFTYPE *blue, char *errmsg, int *status)
 {
-  char oldfilename[BUFSIZ];
   WS_STATE_ENTRY *ws = OPEN_WSID(*ws_id);
   *status = 0;
 
