@@ -61,21 +61,18 @@
    for aix port *kob* 10/94 */
 
 #include <sys/types.h>
+#include <ctype.h>
 #include <dirent.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include "fmtprotos.h"
 
 
-
-int tilda_strcmp( rootnam, testnam )
-
-   char rootnam[], testnam[];
-
+static int tilda_strcmp(char *rootnam, char *testnam)
 /* compare root name with test to see if they match apart from ".~nnn~"
    If they do, return nnn (0 for identical match).
    Else return -1  */
-
 {
    int rlen, tlen, i, tilda;
    char tbuff[4];
@@ -115,14 +112,11 @@ int tilda_strcmp( rootnam, testnam )
 }
 
 
-int high_ver_name(name,path)
-  char name[], path[];
+int high_ver_name(char *name, char *path)
 /* find the highest numbered version of file "name" in the given directory */
 /* if no directory is given then the current directory is used.         */
 /* Also, if given path does not exist, then the procedure is exited  */
 /* modified 10/91 to do this        <kob> */
-
-
 {
   int next, tilda=(-1);
   struct dirent *dp;
@@ -145,17 +139,10 @@ int high_ver_name(name,path)
   }
 
   return tilda; 
-	    
 }
 
-#ifdef NO_ENTRY_NAME_UNDERSCORES
-char *tm_c_ver_name(name, next_name,path)
-#else
-char *tm_c_ver_name_(name, next_name,path)
-#endif
-  char name[], next_name[], path[];
+char *FORTRAN(tm_c_ver_name)(char *name, char *next_name, char *path)
 /* generate the name for the next version of a file in this directory */
-
 {
   int high, len;
 
@@ -180,5 +167,3 @@ char *tm_c_ver_name_(name, next_name,path)
   return next_name;
 }
 
-
-
