@@ -60,41 +60,22 @@
 /* *kob* 10/03 v553 - gcc v3.x needs wchar.h included */
 
 #include <wchar.h>
-#include "udposix.h"
-#include "gks_implem.h"
-#include "cgm/cgm.h"
-#include "cgm/cgm_implem.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <time.h> 
+#include "udposix.h"
+#include "gks_implem.h"
+#include "cgm/cgm.h"
+#include "cgm/cgm_implem.h"
+#include "pplmem.h"
 
-#ifdef NO_ENTRY_NAME_UNDERSCORES
-resize_xgks_window (ws_id, x, y, ix, iy)
-#else
-resize_xgks_window_ (ws_id, x, y, ix, iy)
-#endif
-
-Gint *ws_id;
-float *x;
-float *y;
-int   *ix,*iy;
-
+void FORTRAN(resize_xgks_window)(int *ws_id, float *x, float *y, int *ix, int *iy)
 {
   WS_STATE_ENTRY *ws;
-
-  Display       **dpy;
-  Window         *win;
-  GC             *gc;
-
-  XEvent          evnt;
-  Gint            val;
   Gpoint          size;
-
   float           xf,yf,aspect;
-
-  int             xw_event,scr; 
-  time_t          t0,t_now,*tp;
+  int             scr; 
 
 /*****************************************************************************/
 
@@ -127,17 +108,6 @@ int   *ix,*iy;
   if (ws){
     if (ws->ewstype == X_WIN && ws->dpy){
       XResizeWindow (ws->dpy,ws->win,*ix,*iy);
-      tp = &t_now;
-      t0 = time(0);
-  
-/*
- *    do { 
- *    xw_event = XCheckWindowEvent (ws->dpy,ws->win,StructureNotifyMask,&evnt);
- *     time (tp);
- *   } while (xw_event && (t_now - t0 < 3));
- *
- */
-
     } else if (ws->ewstype == MO){
       int type = ws->mf.cgmo->type;
       if (type == MF_GIF){
